==> qtjambi-qt3drender-5.15.8-sources.jar: io/qt/qt3d/render/QTextureGenerator.java <==
package io.qt.qt3d.render;


/**
 * <p>Provides the image data for a texture</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qt3drender-qtexturegenerator.html">Qt3DRender::QTextureGenerator</a></p>
 */
public interface QTextureGenerator extends io.qt.QtObjectInterface, io.qt.qt3d.render.QAbstractFunctor
{
    /**
     * <p>Implementor class for interface {@link io.qt.qt3d.render.QTextureGenerator}</p>
     */
    public static abstract class Impl extends io.qt.QtObject
        implements io.qt.qt3d.render.QTextureGenerator,
                io.qt.qt3d.render.QAbstractFunctor
    {
        static {
            QtJambi_LibraryUtilities.initialize();
        }
        
        @io.qt.NativeAccess
        private static final class ConcreteWrapper extends QTextureGenerator.Impl {
            
            @io.qt.NativeAccess
            private ConcreteWrapper(QPrivateConstructor p) { super(p); }
            
            @Override
            @io.qt.QtUninvokable
            public io.qt.qt3d.render.QTextureData get(){
                return get_native(QtJambi_LibraryUtilities.internal.nativeId(this));
            }
            private native static io.qt.qt3d.render.QTextureData get_native(long __this__nativeId);
            
            
            @Override
            @io.qt.QtUninvokable
            public boolean equals(io.qt.qt3d.render.QTextureGenerator other){
                java.util.Objects.requireNonNull(other, "Argument 'other': null not expected.");
                return equals_native_cref_Qt3DRender_QTextureGenerator_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
            }
            private native static boolean equals_native_cref_Qt3DRender_QTextureGenerator_constfct(long __this__nativeId, long other);
            
        }
        
        
        public Impl(){
            super((QPrivateConstructor)null);
            initialize_native(this);
        }
        
        private native static void initialize_native(QTextureGenerator instance);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qtexturegenerator.html#operator-28-29">Qt3DRender::QTextureGenerator::operator()()</a></p>
         */
        @io.qt.QtUninvokable
        public abstract io.qt.qt3d.render.QTextureData get();
        
        private native static io.qt.qt3d.render.QTextureData get_native(long __this__nativeId);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qtexturegenerator.html#operator-eq-eq">Qt3DRender::QTextureGenerator::operator==(Qt3DRender::QTextureGenerator)const</a></p>
         */
        @io.qt.QtUninvokable
        public abstract boolean equals(io.qt.qt3d.render.QTextureGenerator other);
        
        private native static boolean equals_native_cref_Qt3DRender_QTextureGenerator_constfct(long __this__nativeId, long other);
        
        /**
         * Constructor for internal use only.
         * @param p expected to be <code>null</code>.
         */
        @io.qt.NativeAccess
        protected Impl(QPrivateConstructor p) { super(p); } 
        

        @Override
        @io.qt.QtUninvokable
        public boolean equals(Object other) {
            if (other instanceof io.qt.qt3d.render.QTextureGenerator) {
                return equals((io.qt.qt3d.render.QTextureGenerator) other);
            }

            return false;
        }

    }

    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qtexturegenerator.html#operator-28-29">Qt3DRender::QTextureGenerator::operator()()</a></p>
     */
    @io.qt.QtUninvokable
    public io.qt.qt3d.render.QTextureData get();
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qtexturegenerator.html#operator-eq-eq">Qt3DRender::QTextureGenerator::operator==(Qt3DRender::QTextureGenerator)const</a></p>
     */
    @io.qt.QtUninvokable
    public default boolean equals(io.qt.qt3d.render.QTextureGenerator other){
        return this==other;
    }
    
}

==> qtjambi-qt3drender-5.15.13-sources.jar: io/qt/qt3d/render/QTextureGenerator.java <==
package io.qt.qt3d.render;


/**
 * <p>Provides the image data for a texture</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qt3drender-qtexturegenerator.html">Qt3DRender::QTextureGenerator</a></p>
 */
public interface QTextureGenerator extends io.qt.QtObjectInterface, io.qt.qt3d.render.QAbstractFunctor
{
    /**
     * <p>Implementor class for interface {@link io.qt.qt3d.render.QTextureGenerator}</p>
     */
    public static abstract class Impl extends io.qt.QtObject
        implements io.qt.qt3d.render.QTextureGenerator,
                io.qt.qt3d.render.QAbstractFunctor
    {
        static {
            QtJambi_LibraryUtilities.initialize();
        }
        
        @io.qt.NativeAccess
        private static final class ConcreteWrapper extends QTextureGenerator.Impl {
            
            @io.qt.NativeAccess
            private ConcreteWrapper(QPrivateConstructor p) { super(p); }
            
            @Override
            @io.qt.QtUninvokable
            public io.qt.qt3d.render.QTextureData get(){
                return get_native(QtJambi_LibraryUtilities.internal.nativeId(this));
            }
            private native static io.qt.qt3d.render.QTextureData get_native(long __this__nativeId);
            
            
            @Override
            @io.qt.QtUninvokable
            public boolean equals(io.qt.qt3d.render.QTextureGenerator other){
                java.util.Objects.requireNonNull(other, "Argument 'other': null not expected.");
                return equals_native_cref_Qt3DRender_QTextureGenerator_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
            }
            private native static boolean equals_native_cref_Qt3DRender_QTextureGenerator_constfct(long __this__nativeId, long other);
            
        }
        
        
        public Impl(){
            super((QPrivateConstructor)null);
            initialize_native(this);
        }
        
        private native static void initialize_native(QTextureGenerator instance);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qtexturegenerator.html#operator-28-29">Qt3DRender::QTextureGenerator::operator()()</a></p>
         */
        @io.qt.QtUninvokable
        public abstract io.qt.qt3d.render.QTextureData get();
        
        private native static io.qt.qt3d.render.QTextureData get_native(long __this__nativeId);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qtexturegenerator.html#operator-eq-eq">Qt3DRender::QTextureGenerator::operator==(Qt3DRender::QTextureGenerator)const</a></p>
         */
        @io.qt.QtUninvokable
        public abstract boolean equals(io.qt.qt3d.render.QTextureGenerator other);
        
        private native static boolean equals_native_cref_Qt3DRender_QTextureGenerator_constfct(long __this__nativeId, long other);
        
        /**
         * Constructor for internal use only.
         * @param p expected to be <code>null</code>.
         */
        @io.qt.NativeAccess
        protected Impl(QPrivateConstructor p) { super(p); } 
        

        @Override
        @io.qt.QtUninvokable
        public boolean equals(Object other) {
            if (other instanceof io.qt.qt3d.render.QTextureGenerator) {
                return equals((io.qt.qt3d.render.QTextureGenerator) other);
            }

            return false;
        }

    }

    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qtexturegenerator.html#operator-28-29">Qt3DRender::QTextureGenerator::operator()()</a></p>
     */
    @io.qt.QtUninvokable
    public io.qt.qt3d.render.QTextureData get();
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qtexturegenerator.html#operator-eq-eq">Qt3DRender::QTextureGenerator::operator==(Qt3DRender::QTextureGenerator)const</a></p>
     */
    @io.qt.QtUninvokable
    public default boolean equals(io.qt.qt3d.render.QTextureGenerator other){
        return this==other;
    }
    
}
